@@ -184,13 +184,14 @@ class RandomLineAccessFile(BaseRandomLineAccessFile[str]):
     :vartype file: Optional[TextIO]
     """
 
-    def __init__(self, path_to: str, line_offsets: Optional[Sequence[int]] = None):
+    def __init__(self, path_to: str, line_offsets: Optional[Union[Sequence[int], str]] = None):
         """
         initialization
         Makes just the line offsets index. Whole file itself is not loaded into memory.
 
         :param path_to: path to file
         :param line_offsets: Pre-created index of line offsets. If None it will be created automatically
+            or path to file with line offsets on each line for each line in file (starts from 0).
         """
 
         super().__init__(path_to)
@@ -198,8 +199,21 @@ class RandomLineAccessFile(BaseRandomLineAccessFile[str]):
         self._lines = line_offsets
         if line_offsets is None:
             self._index_file()
+        elif isinstance(line_offsets, str):
+            self._lines = self.read_index_from_file(line_offsets)
         self._opened_in_process_with_id = None
 
+    @staticmethod
+    def read_index_from_file(path_to: str):
+        """
+        Reads line offsets from file.
+
+        :param path_to: path to file with line offsets
+        :return: list of line offsets
+        """
+        with open(path_to, "r") as f:
+            return [int(line) for line in f]
+
     def _index_file(self):
         """
         Makes index of line offsets.
@@ -237,7 +251,7 @@ class RandomLineAccessFile(BaseRandomLineAccessFile[str]):
             self.file = None
             self._opened_in_process_with_id = None
 
-    def _reopen_if_needed(self):
+    def reopen_if_needed(self):
         """
         Reopens itself if the multiprocessing is activated and this dataset was opened in parent process.
         """
@@ -252,7 +266,7 @@ class RandomLineAccessFile(BaseRandomLineAccessFile[str]):
         return self.file is None
 
     def _file_seek(self, offset: int):
-        self._reopen_if_needed()
+        self.reopen_if_needed()
         self.file.seek(offset)
 
     def _read_line(self, n: int) -> str:
@@ -260,12 +274,12 @@ class RandomLineAccessFile(BaseRandomLineAccessFile[str]):
         return self._read_next_line()
 
     def _read_next_line(self) -> str:
-        self._reopen_if_needed()
+        self.reopen_if_needed()
         return self.file.readline().rstrip("\n")
 
 
 class MemoryMappedRandomLineAccessFile(RandomLineAccessFile):
-    def __init__(self, path_to: str, line_offsets: Optional[Sequence[int]] = None):
+    def __init__(self, path_to: str, line_offsets: Optional[Union[Sequence[int], str]] = None):
         super().__init__(path_to, line_offsets)
         self.mm = None
 
@@ -285,7 +299,7 @@ class MemoryMappedRandomLineAccessFile(RandomLineAccessFile):
             self._opened_in_process_with_id = None
 
     def _file_seek(self, offset: int):
-        self._reopen_if_needed()
+        self.reopen_if_needed()
         self.mm.seek(offset)
 
     def _read_line(self, n: int) -> str:
@@ -293,7 +307,7 @@ class MemoryMappedRandomLineAccessFile(RandomLineAccessFile):
         return self._read_next_line()
 
     def _read_next_line(self) -> str:
-        self._reopen_if_needed()
+        self.reopen_if_needed()
         return self.mm.readline().decode().rstrip("\n")
 
 
@@ -784,7 +798,7 @@ class MapAccessFile:
             self.file = None
             self._opened_in_process_with_id = None
 
-    def _reopen_if_needed(self):
+    def reopen_if_needed(self):
         """
         Reopens itself if the multiprocessing is activated and this dataset was opened in parent process.
         """
@@ -804,7 +818,7 @@ class MapAccessFile:
         """
         if self.file is None:
             raise RuntimeError("Firstly open the file.")
-        self._reopen_if_needed()
+        self.reopen_if_needed()
         self.file.seek(self.mapping[k])
         return self.file.readline()
 
